BindGroupLayout

Struct BindGroupLayout 

pub struct BindGroupLayout { /* private fields */ }
Handle to a binding group layout.

A BindGroupLayout is a handle to the GPU-side layout of a binding group. It can be used to create a BindGroupDescriptor object, which in turn can be used to create a BindGroup object with Device::create_bind_group. A series of BindGroupLayouts can also be used to create a PipelineLayoutDescriptor, which can be used to create a PipelineLayout.

It can be created with Device::create_bind_group_layout.

Corresponds to WebGPU GPUBindGroupLayout.

Implementations

Source

impl BindGroupLayout

pub fn global_id(&self) -> Id<BindGroupLayout>

Returns a globally-unique identifier for this BindGroupLayout.

Calling this method multiple times on the same object will always return the same value. The returned value is guaranteed to be different for all resources created from the same Instance.