pub trait SystemSet:
'static
+ Send
+ Sync
+ Debug {
// Required methods
fn dyn_clone(&self) -> Box<dyn SystemSet>;
fn as_dyn_eq(&self) -> &(dyn DynEq + 'static);
fn dyn_hash(&self, state: &mut dyn Hasher);
// Provided methods
fn system_type(&self) -> Option<TypeId> { ... }
fn is_anonymous(&self) -> bool { ... }
fn intern(&self) -> Interned<dyn SystemSet>
where Self: Sized { ... }
}Expand description
Types that identify logical groups of systems.
Required Methods
Provided Methods
Sourcefn system_type(&self) -> Option<TypeId>
fn system_type(&self) -> Option<TypeId>
Returns Some if this system set is a SystemTypeSet.
Sourcefn is_anonymous(&self) -> bool
fn is_anonymous(&self) -> bool
Returns true if this system set is an AnonymousSet.